#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
infraless/controllers/base.py

"""

from cement import Controller, ex
from cement.utils.version import get_version_banner

from ..core.version import get_version

VERSION_BANNER = """
Framework to build automated web platforms %s
%s
""" % (get_version(), get_version_banner())


class Base(Controller):
    class Meta:
        label = 'base'

        # text displayed at the top of --help output
        description = 'Framework to build automated web platforms'

        # text displayed at the bottom of --help output
        epilog = 'Usage: infraless command <subcommand> <args>'

        # controller level arguments. ex: 'infraless --version'
        arguments = [
            # add a version banner
            (['-v', '--version'], {
                'action': 'version',
                'version': VERSION_BANNER
            }),
        ]

    def _default(self):
        """Default action if no sub-command is passed."""

        self.app.args.print_help()

    @ex(
        help='test command',

        # sub-command level arguments. ex: 'infraless command1 --foo bar'
        arguments=[
            # add a sample foo option under subcommand namespace
            (['-f', '--foo'], {
                'help': 'notorious foo option',
                'action': 'store',
                'dest': 'foo'
            }),
        ],
    )
    def test(self):
        """
        CLI test command.
        """

        data = {
            'foo': 'bar',
        }

        # do something with arguments
        if self.app.pargs.foo is not None:
            data['foo'] = self.app.pargs.foo
        self.app.render(data, 'test.jinja2')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
infraless/main.py

"""
from cement import App, TestApp, init_defaults
from cement.core.exc import CaughtSignal

from .controllers.base import Base
from .core.exc import InfralessError
from .core import helpers as hlprs

# configuration defaults
CONFIG = init_defaults('todo')
CONFIG['todo']['foo'] = 'bar'


class InfraLess(App):
    """InfraLess CLI primary application."""

    class Meta:
        label = 'infraless'

        # configuration defaults
        config_defaults = CONFIG

        # call sys.exit() on close
        close_on_exit = True

        # load additional framework extensions
        extensions = [
            'yaml',
            'colorlog',
            'jinja2',
        ]

        # configuration handler
        config_handler = 'yaml'

        # configuration file suffix
        config_file_suffix = '.yml'

        # set the log handler
        log_handler = 'colorlog'

        # set the output handler
        output_handler = 'jinja2'

        # register handlers
        handlers = [Base]


class InfraLessTest(TestApp, InfraLess):
    """A sub-class of InfraLess that is better suited for testing."""

    class Meta:
        label = 'infraless'


def main():
    with InfraLess() as app:
        try:
            hlprs.log('InfraLess', 'green', figlet=True, on_color='on_blue')
            # print(
            #     colored(
            #         figlet_format('Infra Less', font='slant'), 'green',
            #         'on_blue'))
            app.run()

        except AssertionError as e:
            print('AssertionError > %s' % e.args[0])
            app.exit_code = 1

            if app.debug is True:
                import traceback
                traceback.print_exc()

        except InfralessError as e:
            hlprs.log(e, 'red')
            app.exit_code = 1

            if app.debug is True:
                import traceback
                traceback.print_exc()

        except CaughtSignal as e:
            # Default Cement signals are SIGINT and SIGTERM, exit 0 (non-error)
            print('\n%s' % e)
            app.exit_code = 0


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
infraless/controllers/validators.py

"""
from PyInquirer import (ValidationError, Validator)


class EmptyValidator(Validator):
    def validate(self, value):
        if len(value.text):
            return True
        else:
            raise ValidationError(message="You can't leave this blank",
                                  cursor_position=len(value.text))



from setuptools import setup, find_packages

with open('README.md', 'r') as readme_file:
    LONG_DESCRIPTION = readme_file.read()

with open('requirements.txt') as reqs:
    requirements = reqs.read()

setup(
    name='infraless',
    version='0.0.1-alpha',
    description='Run your code at scale without worrying about the cloud',
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    author='Pulkit Kumar',
    author_email='ispulkitkr@gmail.com',
    url='https://github.com/ispulkit',
    license='unlicensed',
    packages=find_packages(exclude=['ez_setup', 'tests*']),
    package_data={'infraless': ['templates/*']},
    include_package_data=True,
    install_requires=[
        requirements,
    ],
    entry_points="""
        [console_scripts]
        infraless = infraless.cli_router:main
    """,
)



from pyfiglet import figlet_format

try:
    import colorama
    colorama.init()
except ImportError:
    colorama = None

try:
    from termcolor import colored
except ImportError:
    colored = None


def log(string, color, font="slant", figlet=False, on_color=None):
    if colored:
        if not figlet:
            if on_color:
                print(colored(string, color, on_color))
            else:
                print(colored(string, color))
        else:
            if on_color:
                print(
                    colored(figlet_format(string, font=font), color, on_color))
            else:
                print(colored(figlet_format(string, font=font), color))
    else:
        print(string)
